/**
 * Override convention configuration
 * https://github.com/vuejs/vue-cli/blob/dev/docs/config.md
 */
module.exports = {
    // Project deployment base
    // By default we assume your app will be deployed at the root of a domain,
    // e.g. https://www.my-app.com/
    // If your app is deployed at a sub-path, you will need to specify that
    // sub-path here. For example, if your app is deployed at
    // https://www.foobar.com/my-app/
    // then change this to '/my-app/'
    publicPath: '/',   // 基本路径

    // where to output built files
    outputDir: 'dist', // 输出文件目录

    // whether to use eslint-loader for lint on save.
    // valid values: true | false | 'error'
    // when set to 'error', lint errors will cause compilation to fail.
    lintOnSave: true,  // eslint-loader 是否在保存的时候检查

    // use the full build with in-browser compiler?
    // 使用带有浏览器内编译器的完整构建版本
    // https://vuejs.org/v2/guide/installation.html#Runtime-Compiler-vs-Runtime-only
    runtimeCompiler: true,

    // tweak internal webpack configuration.
    // see https://github.com/vuejs/vue-cli/blob/dev/docs/webpack.md // webpack配置

    chainWebpack: config => {},

    configureWebpack: config => {},

    // vue-loader options
    // https://vue-loader.vuejs.org/en/options.html
    //vueLoader: {}, // vue-loader 配置项

    // generate sourceMap for production build?
    productionSourceMap: true, // 生产环境是否生成 sourceMap 文件

    // CSS related options
    css: {
        // extract CSS in components into a single CSS file (only in production)
        extract: true, // 是否使用css分离插件 ExtractTextPlugin

        // enable CSS source maps?
        sourceMap: false,  // 开启 CSS source maps?

        // pass custom options to pre-processor loaders. e.g. to pass options to
        // sass-loader, use { sass: { ... } }
        loaderOptions: {
            // https://www.jianshu.com/p/f2038e10ea17
            sass: {
                // @/ is an alias to src/vue 页面共享的全局变量传递给所有Sass样式
                // so this assumes you have a file named `src/variables.scss`
                data: `@import "@/style/common.scss";`
            }
        }, // css预设器配置项

        // Enable CSS modules for all css / pre-processor files.
        // This option does not affect *.vue files.
        modules: false // 启用 CSS modules for all css / pre-processor files.
    },

    // use thread-loader for babel & TS in production build
    // enabled by default if the machine has more than 1 cores
    parallel: require('os').cpus().length > 1,

    // split vendors using autoDLLPlugin?
    // can also be an explicit Array of dependencies to include in the DLL chunk.
    // See https://github.com/vuejs/vue-cli/blob/dev/docs/cli-service.md#dll-mode
    // dll: false, // 是否启用dll

    // options for the PWA plugin.
    // see https://github.com/vuejs/vue-cli/tree/dev/packages/%40vue/cli-plugin-pwa
    pwa: {},

    // configure webpack-dev-server behavior // webpack-dev-server 相关配置
    devServer: {
        open: process.platform === 'darwin',
        host: '0.0.0.0',
        port: 8080,
        https: false,
        hotOnly: false,
        // See https://github.com/vuejs/vue-cli/blob/dev/docs/cli-service.md#configuring-proxy
        proxy: null, // string | Object
        before: app => {}
    },

    // options for 3rd party plugins // 第三方插件配置
    pluginOptions: {

    }
}
